# Controllo Password 

*nome del file sorgente: ControlloPassword.java*

Il programma *ControlloPassword* legge una stringa inserita dall'utente ed effettua una sequenza di test per verificarne la robustezza. Come risultato stampa un rapporto che indica, per ogni test effettuato, se è stato superato o meno. Vengono effettuati quattro diversi test, ciascuno dei quali è definito come la verifica di una condizione sulla password inserita. I test verificano se:

1. la password è composta da almeno 5 caratteri (TEST 1);

2. la password contiene almeno una maiuscola e almeno una cifra decimale (0,1, ..., 9) (TEST 2);

3. tutti i caratteri in posizioni dispari sono consonanti (TEST 3);

4. i caratteri in posizioni pari formano una stringa palindroma (case sensitive) (TEST 4).

Si fornisca un'implementazione del programma che, una volta letta la password, stampi il rapporto e termini.

## Esempio di esecuzione

L'utente inserisce questa password:

		B6Gza4t6XHtHauGiB

Il programma stampa questo report:

		TEST 1: ok
		TEST 2: ok
		TEST 3: fallito
		TEST 4: ok

L'utente inserisce questa password:

		1cGz

Il programma stampa questo report:

		TEST 1: fallito
		TEST 2: ok
		TEST 3: ok
		TEST 4: fallito


## Info utili

Estratto della tabella ASCII.


| CODICE |  CARATTERE  |                      DESCRIZIONE                      |
|--------|-------------|-------------------------------------------------------|
|     32 | (space)     | (space)                                               |
|     33 | !           | (exclamation mark)                                    |
|     34 | "           | (Quotation mark)                                      |
|     35 | #           | (Number sign)                                         |
|     36 | $           | (Dollar sign)                                         |
|     37 | %           | (Percent sign)                                        |
|     38 | &           | (Ampersand)                                           |
|     39 | '           | (Apostrophe)                                          |
|     40 | (           | (round brackets or parentheses)                       |
|     41 | )           | (round brackets or parentheses)                       |
|     42 | *           | (Asterisk)                                            |
|     43 | +           | (Plus sign)                                           |
|     44 | ,           | (Comma)                                               |
|     45 | -           | (Hyphen)                                              |
|     46 | .           | (Full stop , dot)                                     |
|     47 | /           | (Slash)                                               |
|     48 | 0           | (number zero)                                         |
|     49 | 1           | (number one)                                          |
|     50 | 2           | (number two)                                          |
|     51 | 3           | (number three)                                        |
|     52 | 4           | (number four)                                         |
|     53 | 5           | (number five)                                         |
|     54 | 6           | (number six)                                          |
|     55 | 7           | (number seven)                                        |
|     56 | 8           | (number eight)                                        |
|     57 | 9           | (number nine)                                         |
|     58 | :           | (Colon)                                               |
|     59 | ;           | (Semicolon)                                           |
|     60 | <           | (Less-than sign )                                     |
|     61 | =           | (Equals sign)                                         |
|     62 | >           | (Greater-than sign)                                   |
|     63 | ?           | (Question mark)                                       |
|     64 | @           | (At sign)                                             |
|     65 | A           | (Capital A )                                          |
|     66 | B           | (Capital B )                                          |
|     67 | C           | (Capital C )                                          |
|     68 | D           | (Capital D )                                          |
|     69 | E           | (Capital E )                                          |
|     70 | F           | (Capital F )                                          |
|     71 | G           | (Capital G )                                          |
|     72 | H           | (Capital H )                                          |
|     73 | I           | (Capital I )                                          |
|     74 | J           | (Capital J )                                          |
|     75 | K           | (Capital K )                                          |
|     76 | L           | (Capital L )                                          |
|     77 | M           | (Capital M )                                          |
|     78 | N           | (Capital N )                                          |
|     79 | O           | (Capital O )                                          |
|     80 | P           | (Capital P )                                          |
|     81 | Q           | (Capital Q )                                          |
|     82 | R           | (Capital R )                                          |
|     83 | S           | (Capital S )                                          |
|     84 | T           | (Capital T )                                          |
|     85 | U           | (Capital U )                                          |
|     86 | V           | (Capital V )                                          |
|     87 | W           | (Capital W )                                          |
|     88 | X           | (Capital X )                                          |
|     89 | Y           | (Capital Y )                                          |
|     90 | Z           | (Capital Z )                                          |
|     91 | \[          | (square brackets)                     |
|     92 | \\          | (Backslash)                                           |
|     93 | \]          | (square brackets)                     |
|     94 | ^           | (Caret or circumflex accent)                          |
|     95 | _           | (underscore)     |
|     96 | `           | (Grave accent)                                        |
|     97 | a           | (Lowercase  a )                                       |
|     98 | b           | (Lowercase  b )                                       |
|     99 | c           | (Lowercase  c )                                       |
|    100 | d           | (Lowercase  d )                                       |
|    101 | e           | (Lowercase  e )                                       |
|    102 | f           | (Lowercase  f )                                       |
|    103 | g           | (Lowercase  g )                                       |
|    104 | h           | (Lowercase  h )                                       |
|    105 | i           | (Lowercase  i )                                       |
|    106 | j           | (Lowercase  j )                                       |
|    107 | k           | (Lowercase  k )                                       |
|    108 | l           | (Lowercase  l )                                       |
|    109 | m           | (Lowercase  m )                                       |
|    110 | n           | (Lowercase  n )                                       |
|    111 | o           | (Lowercase  o )                                       |
|    112 | p           | (Lowercase  p )                                       |
|    113 | q           | (Lowercase  q )                                       |
|    114 | r           | (Lowercase  r )                                       |
|    115 | s           | (Lowercase  s )                                       |
|    116 | t           | (Lowercase  t )                                       |
|    117 | u           | (Lowercase  u )                                       |
|    118 | v           | (Lowercase  v )                                       |
|    119 | w           | (Lowercase  w )                                       |
|    120 | x           | (Lowercase  x )                                       |
|    121 | y           | (Lowercase  y )                                       |
|    122 | z           | (Lowercase  z )                                       |
|    123 | {           | (curly brackets or braces)                            |
|    124 | \|          | (vertical-bar) |
|    125 | }           | (curly brackets or braces)                            |
|    126 | ~           | (Tilde)                                               |
